<?php
/**
 * This file is part of
 * pragmaMx - Web Content Management System.
 * Copyright by pragmaMx Developer Team - http://www.pragmamx.org
 *
 * pragmaMx is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * $Revision: 1.6.2.5 $
 * $Author: tora60 $
 * $Date: 2009/05/14 23:48:44 $
 */

/**
 * pmxHeader
 *
 * @package pragmaMx
 * @author tora60
 * @copyright Copyright (c) 2008
 * @version $Id: Header.php,v 1.6.2.5 2009/05/14 23:48:44 tora60 Exp $
 * @access public
 */
class pmxHeader {
    private static $__adds = array();

    private static $__urls = array();

    /**
     * pmxHeader::__construct()
     * Ein private Konstruktor; verhindert die direkte Erzeugung des Objektes
     */
    private function __construct()
    {
    }

    /**
     * Returns content of the output
     *
     * @returns array
     * @static
     */
    public static function get()
    {
        $buf = pmxHeader::fetch();
        $buf = trim(implode("\n", array_unique($buf)));
        /* unnoetige spaces entfernen */
        $buf = trim(preg_replace('#\s*\n\s+#', "\n", $buf));
        return $buf;
    }

    /**
     * Outputs content of the buffer and delete the buffer
     *
     * @returns string
     * @static
     */
    public static function show()
    {
        // Puffer ausgeben
        echo '<!-- start~header~' . MX_TIME . '~pmx -->', self::get(), '<!-- end~header~' . MX_TIME . '~pmx -->';
    }

    /**
     * pmxHeader::move()
     *
     * @param mixed $showed
     * @return
     */
    public static function move($showed)
    {
        $pattern = '#<!-- start~header~' . MX_TIME . '~pmx -->.*?<!-- end~header~' . MX_TIME . '~pmx -->#s';
        if (preg_match($pattern, $showed, $matches)) {
            $showed = str_replace($matches[0], self::get(), $showed);
        }
        return $showed;
    }

    /**
     * pmxHeader::fetch()
     * Einstellungen pruefen und komplettieren
     *
     * @param mixed $defaults
     * @return
     */
    public static function fetch($defaults = false)
    {
        $user = self::get_user(); // als erstes abfragen, weil in my_header noch Zuweisungen stehen knnten
        $export = array();
        $export['script_code'] = self::get_script_code();
        $export['style_code'] = self::get_style_code();
        $export['style'] = self::get_style();
        $export['script'] = self::get_script();
        $export['more'] = self::get_more();
        $export['user'] = $user;
        return $export;
    }

    /**
     * pmxHeader::add()
     * Adds code to output buffer
     *
     * @param string $code code for output
     * @return
     */
    public static function add($code)
    {
        if (is_array($code)) {
            foreach ($code as $item) {
                $item = self::_splitmore($item);
                self::$__adds['more'][] = $item;
            }
        } else {
            $code = self::_splitmore($code);
            self::$__adds['more'][] = $code;
        }
        // print '<h1>ADD</h1>';
    }

    /**
     * pmxHeader::add_style()
     *
     * @param mixed $src
     * @param string $media
     * @param string $if_for_ie
     * @return
     */
    public static function add_style($src, $media = '', $if_for_ie = '')
    {
        if (!$src) {
            return false;
        }

        if ($media) {
            $media = ' media="' . $media . '"';
        }

        /* PMX_BASE_PATH am Anfang entfernen */
        $src = self::_stripbasepath($src);

        /* verhindern, dass url doppelt eingefuegt wird */
        if (in_array($src, self::$__urls)) {
            return true;
        }
        self::$__urls[] = $src;

        $src = '<link rel="stylesheet" type="text/css" href="' . trim($src) . '"' . $media . ' />';
        if ($if_for_ie) {
            $src = "<!--[if " . $if_for_ie . "]>\n" . $src . "\n<![endif]-->";
        }

        self::$__adds['style'][] = $src;
    }

    /**
     * pmxHeader::add_style_code()
     *
     * @param mixed $code
     * @return
     */
    public static function add_style_code($code)
    {
        self::$__adds['style_code'][] = preg_replace(array('#[[:cntrl:]]#', '#\s+#'), array('', ' '), $code);
    }

    /**
     * pmxHeader::add_script()
     *
     * @param mixed $src
     * @param string $if_for_ie
     * @return
     */
    public static function add_script($src, $if_for_ie = '')
    {
        /* PMX_BASE_PATH am Anfang entfernen */
        $src = self::_stripbasepath($src);

        /* verhindern, dass url doppelt eingefuegt wird */
        if (in_array($src, self::$__urls)) {
            return true;
        }
        self::$__urls[] = $src;

        $src = '<script type="text/javascript" src="' . trim($src) . '"></script>';
        if ($if_for_ie) {
            $src = "<!--[if " . $if_for_ie . "]>\n" . $src . "\n<![endif]-->";
        }

        self::$__adds['script'][] = $src;
    }

    /**
     * pmxHeader::add_script_code()
     *
     * @param mixed $code
     * @return
     */
    public static function add_script_code($code)
    {
        self::$__adds['script_code'][] = $code;
    }

    /**
     * pmxHeader::get_style()
     *
     * @return
     */
    public static function get_style()
    {
        if (array_key_exists('style', self::$__adds)) {
            return implode("\n", array_unique(self::$__adds['style'])) . "\n";
        }
    }

    /**
     * pmxHeader::get_style_code()
     *
     * @return
     */
    public static function get_style_code()
    {
        if (array_key_exists('style_code', self::$__adds)) {
            return self::_preparelines(self::$__adds['style_code'], 'style') . "\n";
        }
    }

    /**
     * pmxHeader::get_script()
     *
     * @return
     */
    public static function get_script()
    {
        if (array_key_exists('script', self::$__adds)) {
            return implode("\n", array_unique(self::$__adds['script'])) . "\n";
        }
    }

    /**
     * pmxHeader::get_script_code()
     *
     * @return
     */
    public static function get_script_code()
    {
        if (array_key_exists('script_code', self::$__adds)) {
            return self::_preparelines(self::$__adds['script_code'], 'script') . "\n";
        }
    }

    /**
     * pmxHeader::get_more()
     *
     * @return
     */
    public static function get_more()
    {
        /* die Sammlung zurueckgeben... */
        if (array_key_exists('more', self::$__adds)) {
            $more = array_unique(self::$__adds['more']);
            foreach ($more as $key => $value) {
                $more[$key] = preg_replace('#\s*\n\s+#', "\n", $value);
            }
            return implode("\n", $more) . "\n";
        }
    }

    /**
     * pmxHeader::get_user()
     * u.A. die alte my_header.php includen und bearbeiten
     *
     * @return
     */
    public static function get_user()
    {
        /* zusaetzliche Datei fuer benutzerdefinierte Zusaetze im HTML-Headerbereich */
        $my_header = realpath(PMX_SYSTEM_DIR . '/my_header.php');
        if ($my_header) {
            ob_start();
            if (include_once($my_header)) {
                $my_header = trim(ob_get_clean());
                if ($my_header) {
                    self::add($my_header);
                }
            } else {
                ob_end_clean();
            }
        }
    }

    /**
     * only DUMMY !!
     * pmxHeader::set_description()
     * set meta description
     *
     * @param mixed $description
     * @return
     */
    public static function set_description($description)
    {
        return;
    }

    /**
     * only DUMMY !!
     * pmxHeader::set_keywords()
     * set and replace existing keywords
     *
     * @param mixed $keywords
     * @return
     */
    public static function set_keywords($keywords)
    {
        return;
    }

    /**
     * pmxHeader::_preparelines()
     *
     * @param mixed $lines
     * @param mixed $type
     * @return
     */
    private static function _preparelines($lines, $type)
    {
        $lines = trim(implode("\n", array_unique($lines)));
        if (!$lines) {
            return '';
        }
        if ($type === 'script') {
            $out = '<script type="text/javascript">';
        } else {
            $out = '<style type="text/css">';
        }

        $out .= "\n /* <![CDATA[ */\n" . $lines . "\n /* ]]> */\n";

        if ($type === 'script') {
            $out .= '</script>';
        } else {
            $out .= '</style>';
        }
        return $out;
    }

    /**
     * pmxHeader::_stripbasepath()
     *
     * @param mixed $url
     * @return
     */
    private static function _stripbasepath($url)
    {
        /* PMX_BASE_PATH am Anfang entfernen */
        if (strpos($url, PMX_BASE_PATH, 0) === 0) {
            $url = substr($url, strlen(PMX_BASE_PATH));
        }
        return $url;
    }

    /**
     * pmxHeader::_splitmore()
     *
     * @param mixed $code
     * @return
     */
    private static function _splitmore($code)
    {
        // mxDebugFuncVars($code);#exit;
        return $code;
    }
}

?>